@@ -107,14 +107,14 @@ std::ostream &operator<<(std::ostream &o, PictInfo const &info)
     o << "#align=" << info.m_align << ",";
     break;
   }
-  static char const *wh[]= {
-    "", "goTo", "aboutDialog", "print", "quit", "launch", "sound", "QMOV",
-    "note", "export[asText]", "last[chapter]", "TOC[show]", "find", "appleEvent",
-    "next[chapter]", "prev[chapter]", "script"
-  };
-  if (info.m_action >= 0 && info.m_action <= 16)
+  if (info.m_action >= 0 && info.m_action <= 16) {
+    static char const *wh[]= {
+      "", "goTo", "aboutDialog", "print", "quit", "launch", "sound", "QMOV",
+      "note", "export[asText]", "last[chapter]", "TOC[show]", "find", "appleEvent",
+      "next[chapter]", "prev[chapter]", "script"
+    };
     o << wh[info.m_action];
-  else
+  } else
     o << "#action=" << info.m_action << ",";
   switch(info.m_action) {
   case 1:
@@ -448,19 +448,18 @@ bool DMParser::sendPicture(int zId, int lId, double /*lineW*/)
   if (!dataSz) {
     return false;
   }
-  WPXInputStream *dataInput = const_cast<WPXInputStream *>(data.getDataStream());
-  if (!dataInput) {
+  MWAWInputStreamPtr pictInput=MWAWInputStream::get(data, false);
+  if (!pictInput) {
     MWAW_DEBUG_MSG(("DMText::sendPicture: oops can not find an input\n"));
     return false;
   }
-  MWAWInputStreamPtr pictInput(new MWAWInputStream(dataInput, false));
   Box2f box;
   MWAWPict::ReadResult res = MWAWPictData::check(pictInput, dataSz,box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("DMText::sendPicture: can not find the picture\n"));
     return false;
   }
-  dataInput->seek(0,WPX_SEEK_SET);
+  pictInput->seek(0,WPX_SEEK_SET);
   shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
   MWAWPosition pictPos=MWAWPosition(Vec2f(0,0),box.size(), WPX_POINT);
   MWAWPosition::XPos xpos= (info.m_align==1) ? MWAWPosition::XCenter :
