@@ -1037,15 +1037,13 @@ shared_ptr<HMWKZone> HMWKParser::decodeZone(shared_ptr<HMWKZone> zone)
     return zone;
   }
 
-  WPXInputStream *dataInput =
-    const_cast<WPXInputStream *>(zone->getBinaryData().getDataStream());
-  if (!dataInput) {
+  zone->m_input=MWAWInputStream::get(zone->getBinaryData(), false);
+  if (!zone->m_input) {
     MWAW_DEBUG_MSG(("HMWKParser::decodeZone: can not find my input\n"));
     zone.reset();
     return zone;
   }
 
-  zone->m_input.reset(new MWAWInputStream(dataInput, false));
   zone->m_input->seek(0,WPX_SEEK_SET);
   zone->ascii().setStream(zone->m_input);
   static int fId = 0;
@@ -1109,6 +1107,8 @@ bool HMWKParser::checkHeader(MWAWHeader *header, bool strict)
   }
   long tLength = long(input->readULong(4));
   f << "textLength=" << tLength << ",";
+  ascii().addPos(0);
+  ascii().addNote(f.str().c_str());
 
   long pos;
   // title, subject, author, revision, remark, [2 documents tags], mail:
