@@ -58,7 +58,7 @@ std::ostream &operator<<(std::ostream &o, Font const &font)
       o << "=no";
       break;
     case 0x81:
-      o << "=noSyle";
+      o << "=noStyle";
     case 1:
       break;
     default:
@@ -405,7 +405,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
 
 std::ostream &operator<<(std::ostream &o, Section const &section)
 {
-  if (section.m_type.get())
+  if (section.m_type.get()) // 0|0x40|0x80|0xc0
     o << "type=" << std::hex << section.m_type.get() << std::dec << ",";
   if (section.m_paragraphId.isSet() && section.m_paragraphId.get() > -9999)
     o << "sP=" << section.m_paragraphId.get() << ",";
@@ -517,10 +517,23 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     if (dSz < 3) return false;
     m_height = float(input->readLong(2))/1440.f;
     return true;
+  case 0x9a: { // the table shading
+    if (dSz < 2) return false;
+    int sz = (int) input->readULong(1);
+    if (2+sz > dSz || (sz%2)) return false;
+    f << "tableShadings=[";
+    for (int i = 0; i < sz/2; i++) {
+      float gray=1.f-float(input->readULong(2))/10000.f;
+      if (i==0) m_backColor=gray;
+      f << gray << ",";
+    }
+    f << "],";
+    break;
+  }
   case 0x9d: { // table cell shading
     if (dSz < 6) return false;
     val = (int) input->readLong(1); // a small number often 4
-    if (val) f << "backColorUnk=" << val << ",";
+    if (val) f << "backColor[unkn?]=" << val << ",";
     int firstCol = (int) input->readLong(1);
     int lastCol = (int) input->readLong(1);
     if (firstCol < 0 || lastCol < 0 || firstCol+1 > lastCol) {
@@ -529,7 +542,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
       f << "###backRange=" << firstCol << "<->" << lastCol-1 << ",";
       break;
     }
-    float backColor = float(1.-double(input->readULong(2))/10000.);
+    float backColor = 1.f-float(input->readULong(2))/10000.f;
     for (int i = firstCol; i < lastCol; i++)
       getCell(i)->m_backColor = backColor;
     break;
@@ -632,6 +645,7 @@ std::ostream &operator<<(std::ostream &o, Table const &table)
     }
   }
   if (table.m_indent.isSet()) o << "indent=" << table.m_indent.get() << ",";
+  if (table.m_backColor.isSet()) o << "backColor=" << *table.m_backColor << ",";
   if (table.m_columns->size()) {
     o << "cols=[";
     for (size_t i = 0; i < table.m_columns->size(); i++)
@@ -736,14 +750,23 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   case 0x7:
   case 0x8:
   case 0x9:
+  case 0xe: // a small number always 0 ?
     if (dSz < 2) return false;
     val = (int) input->readLong(1);
     switch(c) {
     case 7:
-      m_breakStatus = m_breakStatus.get()|MWAWParagraph::NoBreakBit;
+      if (val==0)
+        m_breakStatus = m_breakStatus.get()&(~MWAWParagraph::NoBreakBit);
+      else
+        m_breakStatus = m_breakStatus.get()|MWAWParagraph::NoBreakBit;
+      f << "noBreak";
       break;
     case 8:
-      m_breakStatus = m_breakStatus.get()|MWAWParagraph::NoBreakWithNextBit;
+      if (val==0)
+        m_breakStatus = m_breakStatus.get()&(~MWAWParagraph::NoBreakWithNextBit);
+      else
+        m_breakStatus = m_breakStatus.get()|MWAWParagraph::NoBreakWithNextBit;
+      f << "noBreakWithNext";
       break;
     case 9: // normally ok, ...
       f << "pagebreakbefore";
@@ -986,7 +1009,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
     if (val&4) f << "Yrel=page,"; // def margin
     if (val&0xF8) f << "#rel=" << (val>>3) << ",";
     break;
-  case 0x1e:
+  case 0x1e: // checkme: find one time in v3 (text struct file) with data 0x80
   case 0x1f:
   case 0x20:
   case 0x21:
@@ -1051,9 +1074,7 @@ std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
 bool Paragraph::getFont(Font &font, Font const *styleFont) const
 {
   bool res = true;
-  if (m_font2.isSet())
-    font = m_font2.get();
-  else if (m_font.isSet())
+  if (m_font.isSet())
     font = m_font.get();
   else
     res = false;
@@ -1092,10 +1113,6 @@ void Paragraph::insert(Paragraph const &para, bool insertModif)
     m_font=para.m_font;
   else if (para.m_font.isSet())
     m_font->insert(*para.m_font);
-  if (!m_font2.isSet())
-    m_font2 = para.m_font2;
-  else if (para.m_font2.isSet())
-    m_font2->insert(*para.m_font2);
   if (insertModif)
     m_modFont->insert(*para.m_modFont);
   if (!m_section.isSet())
@@ -1114,8 +1131,6 @@ void Paragraph::insert(Paragraph const &para, bool insertModif)
 
 void Paragraph::print(std::ostream &o, MWAWFontConverterPtr converter) const
 {
-  if (m_font2.isSet())
-    o << "font2=[" << m_font2->m_font->getDebugString(converter) << m_font2.get() << "],";
   if (m_font.isSet())
     o << "font=[" << m_font->m_font->getDebugString(converter) << m_font.get() << "],";
   if (m_modFont.isSet())
